@@ -54,34 +54,39 @@ class SQLExecute(object):
         self.SQLTransaction = ''
 
     def jqparse(self, obj, path='.'):
-        obj = json.loads(obj) if isinstance(obj, str) else obj
-        find_str, find_map = '', ['["%s"]', '[%s]', '%s', '.%s']
-        for im in path.split('.'):
-            if not im:
-                continue
+        try:
+            obj = json.loads(obj) if isinstance(obj, str) else obj
+            find_str, find_map = '', ['["%s"]', '[%s]', '%s', '.%s']
+            for im in path.split('.'):
+                if not im:
+                    continue
 
-            if isinstance(obj, (list, tuple, str)):
-                if im.startswith('[') and im.endswith(']'):
-                    im = im[1:-1]
-                if ':' in im:
-                    slice_default = [0, len(obj), 1]
-                    obj, quota = obj[slice(
-                        *[int(sli) if sli else slice_default[i] for i, sli in
-                          enumerate(im.split(':'))])], 1
-                else:
-                    obj, quota = obj[int(im)], 1
-            else:
-                if im in obj:
-                    obj, quota = obj[im], 0
-                elif im.endswith('()'):
-                    obj, quota = list(getattr(obj, im[:-2])()), 3
-                else:
-                    if im.isdigit():
-                        obj, quota = obj[int(im)], 1
+                if isinstance(obj, (list, tuple, str)):
+                    if im.startswith('[') and im.endswith(']'):
+                        im = im[1:-1]
+                    if ':' in im:
+                        slice_default = [0, len(obj), 1]
+                        obj, quota = obj[slice(
+                            *[int(sli) if sli else slice_default[i] for i, sli in
+                              enumerate(im.split(':'))])], 1
                     else:
-                        raise KeyError(im)
-            find_str += find_map[quota] % im
-        return obj if isinstance(obj, str) else json.dumps(obj,sort_keys=True,ensure_ascii=False)
+                        obj, quota = obj[int(im)], 1
+                else:
+                    if im in obj:
+                        obj, quota = obj[im], 0
+                    elif im.endswith('()'):
+                        obj, quota = list(getattr(obj, im[:-2])()), 3
+                    else:
+                        if im.isdigit():
+                            obj, quota = obj[int(im)], 1
+                        else:
+                            raise KeyError(im)
+                find_str += find_map[quota] % im
+            return obj if isinstance(obj, str) else json.dumps(obj,sort_keys=True,ensure_ascii=False)
+        except (IndexError, KeyError, ValueError) as je:
+            if "SQLCLI_DEBUG" in os.environ:
+                click.secho("JQ Parse Error: " + repr(je))
+            return "****"
 
     def run(self, statement, p_sqlscript=None):
         """
@@ -181,7 +186,8 @@ class SQLExecute(object):
 
             # 检查SQL中是否包含特殊内容，如果有，改写SQL
             # 特殊内容都有：
-            # 1. ${var}
+            # 1. ${LastSQLResult(.*)}       # .* JQ Parse Pattern
+            # 2. ${var}
             #    用户定义的变量
 
             matchObj = re.search(r"\${LastSQLResult\((.*)\)}",
